# BulkPDFGenerationJobStatus

Job Status

## Enum

* `SUBMITTED` (value: `'Submitted'`)

* `EXECUTING` (value: `'Executing'`)

* `COMPLETED` (value: `'Completed'`)

* `PARTIALCOMPLETE` (value: `'PartialComplete'`)

* `ERROR` (value: `'Error'`)

* `ABORTED` (value: `'Aborted'`)

* `CANCELLED` (value: `'Cancelled'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


